courses.Enrolments (Enrolments) — amici1

# `courses.Enrolments` (Enrolments)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.related.ForeignKey: user>`

- `<django.db.models.fields.related.ForeignKey: printed_by>`

- `<lino.core.choicelists.ChoiceListField: course_area>`

- `<django.db.models.fields.related.ForeignKey: course>`

- `<django.db.models.fields.related.ForeignKey: pupil>`

- `<django.db.models.fields.DateField: request_date>`

- `<lino.core.choicelists.ChoiceListField: state>`

- `<django.db.models.fields.PositiveIntegerField: places>`

- `<django.db.models.fields.CharField: remark>`

- `<lino.core.fields.RichTextField: confirmation_details>`

Detail fields

- `<Panel main_1 in lino_xl.lib.courses.desktop.EnrolmentDetail on lino_xl.lib.courses.desktop.Enrolments>`

- `<Panel main_2 in lino_xl.lib.courses.desktop.EnrolmentDetail on lino_xl.lib.courses.desktop.Enrolments>`

- `<Panel main_3 in lino_xl.lib.courses.desktop.EnrolmentDetail on lino_xl.lib.courses.desktop.Enrolments>`

- Confirmation details (confirmation_details) : See `<lino.core.fields.RichTextField: confirmation_details>`.

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Enrolment.

- Create (submit_insert) : Create the record and open a detail window on it

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- Enrolment (do_print) : Create an excerpt in order to print this data record.

- Clear print cache (clear_printed) : Clear any previously generated printable document. Mark this object as not printed. A subsequent call to print will generate a new cache file.

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

Filter parameters

- `<django.db.models.fields.related.ForeignKey: author>`

- `<lino.core.choicelists.ChoiceListField: state>`

- `<lino.core.choicelists.ChoiceListField: course_state>`

- `<django.db.models.fields.BooleanField: participants_only>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

- `<django.db.models.fields.related.ForeignKey: user>`

## Filter parameters